* Income inequality between men and women in Germany (GSOEP-data)
* ---------------------------------------------------------------

version 10
set more off
capture log close
log using an2, replace

* Data: GSOEP 1997, Sample         
use data1, clear                           	// -> Note 1 
drop ymove - np9507

* Descriptive statistic of income
summarize income
mvdecode income, mv(0=.a)                  	// -> Note 2 
sort gender
by gender:  summarize income
summarize income, detail

* Employment by gender
label define emplb 1 "full time" 2 "part time" 3 "retraining" ///
 4 "irregular" 5 "not working" 6 "military service" 7 "unemployed", modify
label values emp emplb
tabulate emp gender, colum nofreq           	// -> Note 3 

* Preparation for the regression analysis
generate men = gender == 1                  	// gender 
generate fulltime = emp == 1                	// fulltime vs. part-time 
replace fulltime = . if emp >  2            	// -> Note 4 

* Regression analysis I
regress income men fulltime

* Preparation regression analysis II
generate age = 1997 - ybirth                	// age 
egen miss = rowmiss(income fulltime men age)
summarize age if miss==0                    	// -> Note 5 
generate age_z = age - r(mean) if miss == 0
gen agemen = age_z * men                    	// age x gender 

* Regression analysis II
regress income men fulltime age_z agemen

log close
exit

Description
-----------

This is an analysis of income inequality between men and women in Germany.
Hypothesis see Kohler/Kreuter (2009, chapters 1 and 2). The higher amount 
of part time working women is not a sufficient explanation for the inequality
in average income between men and women. And in addition, even though there 
is a higher income inequality among older people, younger women 
are still affected.

Notes:
------

1) SOEP - Education-Sample and random selection of one person per household 
   (Created with crdata1.do).
2) Respondents with income equal to zero are excluded from further analysis
3) Women are more often part time employed than men. It is reasonable to 
   control for employment status. 
4) This command excludes all respondents that are not employed. 
5) Centering the age variable -- see Aiken/West (1991)
